@@ -492,6 +492,10 @@ class Customer(object):
             if OK:
                 break
             try:
+                LOGS.logger.info(
+                    "[customer {}] Fetching CDRs try {}/3"
+                    .format(self.name, i)
+                )
                 response = requests.get(
                     CONFIG['AIGUILLIER']['url_v2'] + "/consommation",
                     auth=(
@@ -500,9 +504,11 @@ class Customer(object):
                     ),
                     params={"client": self.name, "depuis_date": last_date}
                 )
-                LOGS.logger.info("essai {} de {}".format(i, self.name))
-                infos = response['content']
-                LOGS.logger.warn('Value {}'.format(infos))
+                infos = response.json()
+                LOGS.logger.info(
+                    '[customer {}] CDRs count fetched from Aiguiller: {}'
+                    .format(self.name, infos)
+                )
                 if infos['status']:
                     OK = True
             except requests.exceptions.Timeout:
